Struct sortery::messages::error_messages::PathDoesNotExistError [−][src]
pub struct PathDoesNotExistError<'a> {
pub path: &'a File,
}Expand description
When the user inputs a file or directory that doesn’t exist. path is
a File representing the path that does not exist.
Fields
path: &'a File