Struct sortery::messages::ProgressBar [−][src]
The command-line progress bar used when sorting.
-
completed_messageis aStringof the message to be printed whenProgressBar::completeis called. -
messageis aStringto be shown while the progress bar is between start and finish, for example"Still working..."totalis ausizerepresenting the total value of the progress bar. Bar pogress and percent completed are calculated usingtotal. For example, if you are going to sort 20 files, you would pass 20 tototal, and the progress bar would know to show50%whenset_progress(10)is called.
Fields
completed_message: Stringmessage: Stringtotal: usizeImplementations
Print the updated progress bar, with completed number of items completed
out of the total. Automatically calculates percent and bar size.