Function sortery::tools::sort::get_new_date_path[][src]

fn get_new_date_path(
    target: &File,
    old_file: &File,
    date_format: &str,
    date_type: &str,
    preserve_name: bool
) -> File
Move file into a set of directories in yyyy/mm/ format according to its creation time.

Create any required directories that don’t already exist. Also rename the file according to its creation date.