Function sortery::tools::sort::get_sequential_name [−][src]
fn get_sequential_name(path: &File, vec: &Vec<File>) -> FileExpand description
Return a File representing the renamed version of path.
This function is called only if path already exists, but can’t/shouldn’t
be replaced. The naming logic: if /path/to/file already exists, return
/path/to/file_2. If /path/to/file_2 already exists, return /path/to/file_3, etc.